Learn R Programming

snha (version 0.1.3)

snha_get_chains: Return the chains of an snha graph as data frame

Description

This is a utility function to return the chains which constructs the graph as a matrix.

Usage

snha_get_chains(graph)

Value

matrix with one chain per row, shorter chains are filled up with empty strings

Arguments

graph

a snha graph object

Examples

Run this code
data(swiss) 
sw.g=snha(swiss) 
snha_get_chains(sw.g) 

Run the code above in your browser using DataLab