snha_ll: log-likelihood for the given snha graph and the given chain
Description
This function returns the log-likelihood for the given snha
graph and the given chain. If the 'block.p.value' is lower than 0.05 than
that the chain is not sufficient to capture the variable dependencies,
p-values above 0.05 indicate a good coverage of the chain for the linear
dependencies between the nodes.
Usage
snha_ll(graph,chain=NULL)
Value
list with the following components: 'll.total', 'll.chain',
'll.rest', 'll.block', data frame 'df' with the columns 'chisq', 'p.value',
'block.df', 'block.ch', 'block.p.value'. If chain is not given an overall
summary is made for all chains an returned as data frame.
Arguments
graph
a snha graph object
chain
a chain object of a snha graph, if not given a data frame with
the values is returned for all chains, default: NULL