powered by
This is a utility function to return the chains which constructs the graph as a matrix.
snha_get_chains(graph)
matrix with one chain per row, shorter chains are filled up with empty strings
a snha graph object
data(swiss) sw.g=snha(swiss) snha_get_chains(sw.g)
Run the code above in your browser using DataLab